import unittest

from caddo_file_parser.caddo_file_parser import CaddoFileParser


class FileReadingTest(unittest.TestCase):
    def test_file_reading(self):
        caddo_file_parser = CaddoFileParser()
        caddo_file_parser.read_data("results")



import pandas as pd

from caddo_file_parser.models.run import Run
from caddo_file_parser.settings.generation_settings import GenerationSettings


class CaddoFile:
    def __init__(self, runs: [Run], data: pd.DataFrame, settings: GenerationSettings, seeds: []):
        self.runs = runs
        self.data = data
        self.settings = settings
        self.seeds = seeds

